<div class="form-group row">
    <label class="col-12 col-md-3 col-form-label">{{ label|default:input.label }}:</label>
    <div class="col-6">
        {{ input }}
        {% if help_text %}
        <span class="form-text text-muted">{{ help_text }}</span>
        {% endif %}
    </div>
</div>