{% load widget_tweaks base %}
{% comment %} 
# Switch component params:
    - form (required): form object
    - errors (required): field errors (form.errors.FIELD_NAME)
    - input (required): field object (form.FIELD_NAME)
    - classes: Classes to add to the main div $element
    - placeholder: Placeholder text
    - input_classes: Classes on input element
    - help_text: Help text to display below input
{% endcomment %}
<div class="form-group row">
    <div class="col-3"></div>
    <div class="col-auto">
    {% simple_switch_label input=input on_text=on_text off_text=off_text form=form errors=errors children=children help_text=help_text input_classes=input_classes data_disabled=data_disabled %}
    </div>
</div>