{% load static i18n debug cache %}
<!DOCTYPE html>
<html lang="pt">
    <!-- begin::Head -->
    <head>
        <!--begin::Base Path (base relative path for assets of this page) -->
        <base href="../">
        <!--end::Base Path -->
        <meta charset="utf-8" />
        <title>
            {% block title %}{% endblock %}
        </title>
        <meta name="description" content="{% block description %}{% endblock %}">
        <meta name="viewport"
              content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <!--begin::Fonts -->
        <script src="https://ajax.googleapis.com/ajax/libs/webfont/1.6.16/webfont.js"></script>
        <script>
			WebFont.load({
				google: {
					"families": ["Poppins:300,400,500,600,700", "Roboto:300,400,500,600,700"]
				},
				active: function() {
					sessionStorage.fonts = true;
				}
			});
		
        </script>
        <!--end::Fonts -->
        <!--begin:: Global Mandatory Vendors -->
        <link href="{% static 'backoffice/vendors/general/perfect-scrollbar/css/perfect-scrollbar.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <!--end:: Global Mandatory Vendors -->
        <!--begin:: Global Optional Vendors -->
        <link href="{% static 'backoffice/vendors/general/bootstrap-datepicker/dist/css/bootstrap-datepicker3.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/bootstrap-datetime-picker/css/bootstrap-datetimepicker.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/bootstrap-timepicker/css/bootstrap-timepicker.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/bootstrap-daterangepicker/daterangepicker.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/bootstrap-select/dist/css/bootstrap-select.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/bootstrap-switch/dist/css/bootstrap3/bootstrap-switch.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/select2/dist/css/select2.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/nouislider/distribute/nouislider.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/dropzone/dist/dropzone.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/socicon/css/socicon.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/custom/vendors/line-awesome/css/line-awesome.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/custom/vendors/flaticon/flaticon.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/custom/vendors/flaticon2/flaticon.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/vendors/general/@fortawesome/fontawesome-free/css/all.min.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="https://cdn.jsdelivr.net/npm/dual-listbox/dist/dual-listbox.css"
              rel="stylesheet"
              type="text/css">
        <!--end:: Global Optional Vendors -->
        <!--begin::Page Vendors Styles(used by this page) -->
        {% block style_template %}{% endblock %}
        <!--end::Page Vendors Styles -->
        <!--begin::Global Theme Styles(used by all pages) -->
        <link href="{% static 'backoffice/css/style.bundle.min.css' %}"
              rel="stylesheet"
              type="text/css"/>
        <link href="{% static 'backoffice/css/subscriptions-bo.css' %}"
              rel="stylesheet"
              type="text/css">
        <link rel="stylesheet"
              type="text/css"
              href="{% static 'backoffice/css/styled-component.css' %}">
        <link rel="apple-touch-icon"
              sizes="180x180"
              href="https://static-storage.dnoticias.pt/www-assets.dnoticias.pt/apple-icon-180x180.png">
        <link rel="icon"
              type="image/png"
              sizes="16x16"
              href="https://static-storage.dnoticias.pt/www-assets.dnoticias.pt/favicon-16x16.png">
        <!--end::Global Theme Styles -->
        <!--begin::Layout Skins(used by all pages) -->
        <!--begin::Layout Custom -->
        <style>
			.kt-notification .kt-notification__item{
				cursor: pointer;
			}
			.kt-notification .kt-notification__item.kt-notification-no-link:after {
				content: "\f1bc";
			}
			.kt-aside-menu .kt-menu__nav > .kt-menu__item > .kt-menu__heading .kt-menu__ver-arrow, .kt-aside-menu .kt-menu__nav > .kt-menu__item > .kt-menu__link .kt-menu__ver-arrow {font-size: 1rem;}
		
        </style>
        {% block style_develop %}{% endblock %}
        <!--end::Layout Skins -->
        <link rel="apple-touch-icon"
              sizes="180x180"
              href="{% static 'frontoffice/dnoticias/imgs/apple-icon-180x180.png' %}">
        <link rel="icon"
              type="image/png"
              sizes="32x32"
              href="{% static 'frontoffice/dnoticias/imgs/favicon-32x32.png' %}">
        <link rel="shortcut icon"
              type="image/png"
              sizes="16x16"
              href="{% static 'frontoffice/dnoticias/imgs/favicon-16x16.png' %}">
    </head>
    <!-- end::Head -->
    <!-- begin::Body -->
    <body class="kt-header--fixed kt-header-mobile--fixed kt-aside--enabled kt-aside--fixed">
        <!-- begin:: Page -->
        {% include "./includes/header.html" %}
        <!-- end:: Header Mobile -->
        <div class="kt-grid kt-grid--hor kt-grid--root">
            <div class="kt-grid__item kt-grid__item--fluid kt-grid kt-grid--ver kt-page">
                <!-- begin:: Aside -->
                <button class="kt-aside-close " id="kt_aside_close_btn">
                    <i class="la la-close"></i>
                </button>
                {% include "./includes/menu.html" %}
                <!-- end:: Aside -->
                <div class="kt-grid__item kt-grid__item--fluid kt-grid kt-grid--hor kt-wrapper"
                     id="kt_wrapper">
                    <!-- begin:: Header -->
                    <div id="kt_header" class="kt-header kt-grid__item  kt-header--fixed ">
                        <!-- begin: Header Menu -->
                        <button class="kt-header-menu-wrapper-close"
                                id="kt_header_menu_mobile_close_btn">
                            <i class="la la-close"></i>
                        </button>
                        <div class="kt-header-menu-wrapper" id="kt_header_menu_wrapper">
                            <div id="kt_header_menu"
                                 class="kt-header-menu kt-header-menu-mobile  kt-header-menu--layout-default ">
                                <ul class="kt-menu__nav">
                                    <li class="kt-menu__item">
                                        <a href="/" class="kt-menu__link" target="_blank"><span class="kt-menu__link-text kt-shape-font-color-1">{{ SITE_NAME }}</span></a>
                                    </li>
                                </ul>
                            </div>
                        </div>
                        <!-- end: Header Menu -->
                        <!-- begin:: Header Topbar -->
                        <div class="kt-header__topbar">
                            <!--begin: Nav BO's -->
                            {% include "./includes/nav-bo.html" %}
                            <!--end: Nav BO's -->
                            <!--begin: User Bar -->
                            {% include "./includes/user.html" %}
                            <!--end: User Bar -->
                        </div>
                        <!-- end:: Header Topbar -->
                    </div>
                    <!-- end:: Header -->
                    <div class="kt-content kt-grid__item kt-grid__item--fluid kt-grid kt-grid--hor"
                         id="kt_content">
                        {% if messages %}
                            {% include "./includes/messages.html" %}
                        {% endif %}
                        {% block content %}{% endblock %}
                    </div>
                    {% include "./includes/footer.html" %}
            </div>
        </div>
    </div>
    <!-- end:: Page -->
    {% cache None test %}
    <!-- begin::Scrolltop -->
    <div id="kt_scrolltop" class="kt-scrolltop">
        <i class="fa fa-arrow-up"></i>
    </div>
    <!-- end::Scrolltop -->
    <!-- begin::Global Config(global config for global JS sciprts) -->
    <script>
			var KTAppOptions = {
				"colors": {
					"state": {
						"brand": "#2c77f4",
						"light": "#ffffff",
						"dark": "#282a3c",
						"primary": "#5867dd",
						"success": "#34bfa3",
						"info": "#36a3f7",
						"warning": "#ffb822",
						"danger": "#fd3995"
					},
					"base": {
						"label": ["#c5cbe3", "#a1a8c3", "#3d4465", "#3e4466"],
						"shape": ["#f0f3ff", "#d9dffa", "#afb4d4", "#646c9a"]
					}
				}
			};
		
    </script>
    <!-- end::Global Config -->
    <!--begin:: Global Mandatory Vendors -->
    <script src="{% static 'backoffice/vendors/general/jquery/dist/jquery.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/popper.js/dist/umd/popper.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap/dist/js/bootstrap.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/js-cookie/src/js.cookie.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/moment/min/moment.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/moment/locale/pt.js' %}"></script>
    <script src="{% static 'backoffice/vendors/general/tooltip.js/dist/umd/tooltip.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/perfect-scrollbar/dist/perfect-scrollbar.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/sticky-js/dist/sticky.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/wnumb/wNumb.js' %}"
            type="text/javascript"></script>
    <!--end:: Global Mandatory Vendors -->
    <!--begin:: Global Optional Vendors -->
    <script src="{% static 'backoffice/vendors/general/block-ui/jquery.blockUI.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-datepicker/dist/js/bootstrap-datepicker.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-datepicker/js/locales/bootstrap-datepicker.pt.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-datetime-picker/js/bootstrap-datetimepicker.min.js' %}"
            type="text/javascript"></script>
    <script type="text/javascript"
            src="{% static 'backoffice/vendors/general/bootstrap-datetime-picker/js/locales/bootstrap-datetimepicker.pt.js' %}"
            charset="UTF-8"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-timepicker/js/bootstrap-timepicker.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/custom/js/vendors/bootstrap-timepicker.init.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-daterangepicker/daterangepicker.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/custom/vendors/bootstrap-multiselectsplitter/bootstrap-multiselectsplitter.min.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-select/dist/js/bootstrap-select.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/bootstrap-switch/dist/js/bootstrap-switch.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/custom/js/vendors/bootstrap-switch.init.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/select2/dist/js/select2.full.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/select2/dist/js/i18n/pt.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/nouislider/distribute/nouislider.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/owl.carousel/dist/owl.carousel.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/dropzone/dist/dropzone.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/jquery-validation/dist/jquery.validate.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/chart.js/dist/Chart.bundle.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/jquery.repeater/src/lib.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/jquery.repeater/src/jquery.input.js' %}"
            type="text/javascript"></script>
    <script src="{% static 'backoffice/vendors/general/jquery.repeater/src/repeater.js' %}"
            type="text/javascript"></script>
    <!--end:: Global Optional Vendors -->
    <!--begin::Global Theme Bundle(used by all pages) -->
    <script src="{% static 'backoffice/js/scripts.bundle.js' %}"
            type="text/javascript"></script>
    <script src="https://cdn.jsdelivr.net/npm/dual-listbox/dist/dual-listbox.min.js"></script>
    <!--end::Global Theme Bundle -->
    <!--begin::Page Vendors(used by this page) -->
<!--<script src="{% static 'backoffice/vendors/custom/fullcalendar/fullcalendar.bundle.js' %}"
        type="text/javascript"></script>
		<script src="//maps.google.com/maps/api/js?key=AIzaSyBTGnKT7dt597vo9QgeQ7BFhvSRP4eiMSM"
		        type="text/javascript"></script>
<script src="{% static 'backoffice/vendors/custom/gmaps/gmaps.js' %}"
        type="text/javascript"></script>-->
<!--end::Page Vendors -->
{% endcache %}
{% block script_template %}{% endblock %}
<script>
			var scrolltop = new KTScrolltop('kt_scrolltop', {
				offset: 300,
				speed: 600
			});

			$(document).ready(function() {
				var KTBootstrapToasts = function () {
					var toasts = function () {
						// Move element and append to body
						$('#messages').appendTo($('body'));

						$('#messages').toast({
							autohide: false,
						});
						$('#messages').toast('show');
					}

					return {
						// Public functions
						init: function() {
							toasts();
						}
					};
				}();
				KTBootstrapToasts.init();
			});
		
</script>
{% block script_develop %}{% endblock %}
</body>
<!-- end::Body -->
</html>
