<div class="kt-header__topbar-item dropdown">
    <div class="kt-header__topbar-wrapper" data-toggle="dropdown" data-offset="30px,0px" aria-expanded="false">
      <span class="kt-header__topbar-icon">
        <i class="flaticon-app"></i>
      </span>
    </div>
    <div class="dropdown-menu dropdown-menu-right dropdown-menu-anim dropdown-menu-top-unround py-0">
      <ul class="kt-nav">
        <!--begin::Nav-->
        <li class="kt-nav__head">Backoffice</li>
        <li class="kt-nav__separator"></li>
        <li class="kt-nav__item {% if BASE_URL in 'https://bo.dnoticias.pt' %}active{% endif %}">
          <a href="https://bo.dnoticias.pt/dashboard/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-writing"></i>
            <span class="kt-nav__link-text">dnoticias&bull;pt</span>
          </a>
        </li>
        <li class="kt-nav__item {% if BASE_URL in 'https://bo-d7.dnoticias.pt' %}active{% endif %}">
          <a href="https://bo-d7.dnoticias.pt/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-writing"></i>
            <span class="kt-nav__link-text">D7</span>
          </a>
        </li>
        <li class="kt-nav__separator"></li>
        <li class="kt-nav__item {% if BASE_URL in 'https://assinaturas.dnoticias.pt' %}active{% endif %}">
          <a href="https://assinaturas.dnoticias.pt/backoffice/dashboard/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon-folder-1"></i>
            <span class="kt-nav__link-text">Assinaturas</span>
          </a>
        </li>
        <li class="kt-nav__item {% if BASE_URL in 'https://comentarios.dnoticias.pt' %}active{% endif %}">
          <a href="https://comentarios.dnoticias.pt/backoffice/dashboard/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-chat-1"></i>
            <span class="kt-nav__link-text">Comentários</span>
          </a>
        </li>
        <li class="kt-nav__item {% if BASE_URL in 'https://comunicacao.dnoticias.pt' %}active{% endif %}">
          <a href="https://comunicacao.dnoticias.pt/backoffice/dashboard/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-mail-1"></i>
            <span class="kt-nav__link-text">Comunicação</span>
          </a>
        </li>
        <li class="kt-nav__item {% if BASE_URL in 'https://edicao.dnoticias.pt' %}active{% endif %}">
          <a href="https://edicao.dnoticias.pt/backoffice/dashboard/" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-open-text-book"></i>
            <span class="kt-nav__link-text">Edição</span>
          </a>
        </li>
        <li class="kt-nav__item {% if BASE_URL in 'https://analytics.dnoticias.pt' %}active{% endif %}">
          <a href="#" class="kt-nav__link">
            <i class="kt-nav__link-icon flaticon2-analytics-2"></i>
            <span class="kt-nav__link-text">Analytics</span>
          </a>
        </li>
      </ul>
    </div>
  </div>