<div class="row">
    {% if not complete %}<label class="col-xl-3"></label>{% endif %}
    <div class="col-lg-9 col-xl-6">
        <h3 class="kt-section__title kt-section__title-{{ size|default:'lg' }}">{{ title }}</h3>
    </div>
</div>