<div class="form-group row">
    <label class="col-{{ label_rows|default:3 }} col-form-label">{{ label }}</label>
    <div class="col-{{ input_rows|default:6 }}">
        <input type="text" class="form-control" disabled read-only value="{{ value }}">
    </div>
</div>