<!-- begin:: Footer -->
<div class="kt-footer  kt-grid__item kt-grid kt-grid--desktop kt-grid--ver-desktop" id="kt_footer">
    <div class="kt-container  kt-container--fluid ">
        <div class="kt-footer__copyright">
            {% now 'Y' %}&nbsp;&copy;&nbsp;Empresa Diário de Notícias, Lda.
        </div>
        <div class="kt-footer__menu">
            <a href="{{ BASE_URL }}" target="_blank" class="kt-footer__menu-link kt-link">
                {{ SITE_DOMAIN }}
            </a>
        </div>
    </div>
</div>
<!-- end:: Footer -->